# Installation
> `npm install --save @types/d3-transition`

# Summary
This package contains type definitions for D3JS d3-transition module (https://github.com/d3/d3-transition/).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/d3-transition.

### Additional Details
 * Last updated: Wed, 29 Jan 2020 22:02:37 GMT
 * Dependencies: [@types/d3-selection](https://npmjs.com/package/@types/d3-selection)
 * Global values: none

# Credits
These definitions were written by Tom Wanzek (https://github.com/tomwanzek), Alex Ford (https://github.com/gustavderdrache), Boris Yankov (https://github.com/borisyankov), and Robert Moura (https://github.com/robertmoura).
